@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012-2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012 -- leonerd@leonerd.org.uk
 
 package Tickit::StringPos;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.70_001';
+our $VERSION = '0.21';
 
 # XS code comes from Tickit itself
 require Tickit;
@@ -38,11 +38,10 @@ would increment the bytes counter by 2 and the C<codepoints> counter by 1.
 
 The C<codepoints> member counts individual Unicode codepoints.
 
-The C<graphemes> member counts whole composed graphical clusters of
-codepoints, where combining accents which count as individual codepoints do
-not count as separate graphemes. For example, the codepoint sequence U+0065
-U+0301 would increment the C<codepoint> counter by 2 and the C<graphemes>
-counter by 1.
+The C<graphemes> member counts whole composed grahical clusters of codepoints,
+where combining accents which count as individual codepoints do not count as
+separate graphemes. For example, the codepoint sequence U+0065 U+0301 would
+increment the C<codepoint> counter by 2 and the C<graphemes> counter by 1.
 
 The C<columns> member counts the number of screen columns consumed by the
 graphemes. Most graphemes consume only 1 column, but some are defined in
@@ -55,27 +54,17 @@ to -1 to indicate no limit in that counter.
 
 =head1 CONSTRUCTORS
 
-=head2 zero
-
-   $pos = Tickit::StringPos->zero
+=head2 $pos = Tickit::StringPos->zero
 
 Returns a new instance with all counters set to zero.
 
-=head2 limit_bytes
+=head2 $pos = Tickit::StringPos->limit_bytes( $bytes )
 
-=head2 limit_codepoints
+=head2 $pos = Tickit::StringPos->limit_codepoints( $codepoints )
 
-=head2 limit_graphemes
+=head2 $pos = Tickit::StringPos->limit_graphemes( $graphemes )
 
-=head2 limit_columns
-
-   $pos = Tickit::StringPos->limit_bytes( $bytes )
-
-   $pos = Tickit::StringPos->limit_codepoints( $codepoints )
-
-   $pos = Tickit::StringPos->limit_graphemes( $graphemes )
-
-   $pos = Tickit::StringPos->limit_columns( $columns )
+=head2 $pos = Tickit::StringPos->limit_columns( $columns )
 
 Return a new instance with one counter set to the given limit and the other
 three counters set to -1.
@@ -84,21 +73,13 @@ three counters set to -1.
 
 =head1 METHODS
 
-=head2 bytes
+=head2 $bytes = $pos->bytes
 
-=head2 codepoints
+=head2 $codepoints = $pos->codepoints
 
-=head2 graphemes
+=head2 $graphemes = $pos->graphemes
 
-=head2 columns
-
-   $bytes = $pos->bytes
-
-   $codepoints = $pos->codepoints
-
-   $graphemes = $pos->graphemes
-
-   $columns = $pos->columns
+=head2 $columns = $pos->columns
 
 Return the current value the counters.
 
